# Data contracts utility

This data contracts Python utility is a demonstration of what you can do. It is used in my bdp project—blef data platform—where I showcase a data platform mainly built around Dagster and fancy data tools.
